common-specs.transform


edn->json-friendly-transformerclj

source

json-friendly->edn-transformerclj

source

jsonifyclj

(jsonify spec edn)

Transforms the given edn to a JSON-friendly version that can then be transformed into a JSON string.

Transforms the given edn to a JSON-friendly version that can then be transformed into a JSON string.
sourceraw docstring

unjsonifyclj

(unjsonify spec json)

Transforms the given JSON-friendly edn into edn where all JSON-friendly values have been replaced with internal types (dates, enums and so on)

Transforms the given JSON-friendly edn into edn where all JSON-friendly values have been replaced with internal types
(dates, enums and so on)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries