(jsonify spec edn)Transforms the given edn to a JSON-friendly version that can then be transformed into a JSON string.
Transforms the given edn to a JSON-friendly version that can then be transformed into a JSON string.
(unjsonify spec json)Transforms the given JSON-friendly edn into edn where all JSON-friendly values have been replaced with internal types (dates, enums and so on)
Transforms the given JSON-friendly edn into edn where all JSON-friendly values have been replaced with internal types (dates, enums and so on)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |